Descriptive metadata
====================

The ``Descriptive metadata`` tab (keyboard shortcut ``Alt+D``) allows you to edit basic information about your photographs, such as the title and description.

.. image:: ../images/screenshot_07.png

The first thing I usually do with a new set of photographs is to set the copyright and creator/artist metadata.
Select all the images (keyboard shortcut ``Ctrl+A``) then click on the ``Auto`` button next to the ``Copyright`` text entry box.
The first time you do this Photini asks you to provide the name of the copyright holder.
This should probably be your name, but could be the name of a company.
Type in the name and click ``OK``.

The ``Auto`` button generates a standard copyright notice, but if you prefer a different wording you can edit the text manually.

.. image:: ../images/screenshot_08.png

Next click on the ``Creator / Artist`` field's ``Auto`` button.
Now Photini will ask for the name of the creator.
Edit the name if required, then click ``OK``.

.. |hazard| unicode:: U+026A1

Note that all the image thumbnails now have a warning symbol (|hazard|) displayed next to them.
This shows that they have unsaved metadata edits.
The ``File`` menu ``Save images with new data`` item (keyboard shortcut ``Ctrl+S``) saves your edits and clears the warning symbols, as shown below.
I do this frequently to avoid losing any of my work.

.. image:: ../images/screenshot_09.png

Next I set the title.
Select all the images that should have the same title, then type the title in the ``Title / Object name`` text editing box.
Note that the title (and keywords) are stored in XMP but not in EXIF, so may not be visible to software that only handles EXIF metadata (see :doc:`tags` for more detail).
You may prefer to leave the title and keywords fields blank.

.. image:: ../images/screenshot_10.png

Now you can add more detail in the ``Description / Caption`` box.
There are probably only one or two photographs that share the same description, so select those images first.

.. image:: ../images/screenshot_11.png

Finally you can set a list of keywords for the image by typing them in the ``Keywords`` box.
Keywords should be separated by semi-colon (;) characters.